UiDebugValue

Trait UiDebugValue 

pub trait UiDebugValue: Debug + Sized {
    // Required method
    fn ui_debug_type_meta() -> TypeMeta;

    // Provided methods
    fn ui_debug_snapshot(&self) -> String { ... }
    fn emit_snapshot(&self, label: impl Into<String>) { ... }
}
Trait implemented for values that should appear as UI data nodes.

Required Methods

fn ui_debug_type_meta() -> TypeMeta

Returns the static metadata for the type.

Provided Methods

fn ui_debug_snapshot(&self) -> String

Returns the text snapshot shown in the UI.

fn emit_snapshot(&self, label: impl Into<String>)

Emits a value snapshot event for the current session.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors