Module runtime

Module runtime 

Runtime helpers used by generated macros and advanced callers.

Structs

TraceFrame
Guard object representing an active traced function invocation.

Functions

latest_node_id
Returns the node id attached to the most recently recorded event.
preview_argument
Builds a value preview for a traced function argument.
record_test_failed
Records that a test failed and explicitly links it to a node.
record_test_failed_latest
Records that a test failed and links it to the latest active node.
record_test_failed_latest_with_label
Records that a test failed and links it to the latest active node using a custom label.
record_test_passed
Records that a test passed and explicitly links it to a node.
record_test_passed_latest
Records that a test passed and links it to the latest active node.
record_test_passed_latest_with_label
Records that a test passed and links it to the latest active node using a custom label.
record_test_started
Records that a test started and explicitly links it to a node.
record_test_started_latest
Records that a test started and links it to the latest active node.
record_test_started_latest_with_label
Records that a test started and links it to the latest active node using a custom label.
record_type_snapshot
Records a snapshot for a #[ui_debug] value.