Runtime helpers used by generated macros and advanced callers.
Structs
- Trace
Frame - Guard object representing an active traced function invocation.
Functions
- latest_
node_ id - Returns the node id attached to the most recently recorded event.
- preview_
argument - Builds a value preview for a traced function argument.
- record_
test_ failed - Records that a test failed and explicitly links it to a node.
- record_
test_ failed_ latest - Records that a test failed and links it to the latest active node.
- record_
test_ failed_ latest_ with_ label - Records that a test failed and links it to the latest active node using a custom label.
- record_
test_ passed - Records that a test passed and explicitly links it to a node.
- record_
test_ passed_ latest - Records that a test passed and links it to the latest active node.
- record_
test_ passed_ latest_ with_ label - Records that a test passed and links it to the latest active node using a custom label.
- record_
test_ started - Records that a test started and explicitly links it to a node.
- record_
test_ started_ latest - Records that a test started and links it to the latest active node.
- record_
test_ started_ latest_ with_ label - Records that a test started and links it to the latest active node using a custom label.
- record_
type_ snapshot - Records a snapshot for a
#[ui_debug]value.