pub trait UiDebugValue: Debug + Sized {
// Required method
fn ui_debug_type_meta() -> TypeMeta;
// Provided methods
fn ui_debug_snapshot(&self) -> String { ... }
fn emit_snapshot(&self, label: impl Into<String>) { ... }
}Expand description
Trait implemented for values that should appear as UI data nodes.
Required Methods
Sourcefn ui_debug_type_meta() -> TypeMeta
fn ui_debug_type_meta() -> TypeMeta
Returns the static metadata for the type.
Provided Methods
Sourcefn ui_debug_snapshot(&self) -> String
fn ui_debug_snapshot(&self) -> String
Returns the text snapshot shown in the UI.
Sourcefn emit_snapshot(&self, label: impl Into<String>)
fn emit_snapshot(&self, label: impl Into<String>)
Emits a value snapshot event for the current session.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.